import 'dart:typed_data';

import 'package:flutter/material.dart';
import 'package:vone_ipfs/utils/ipfs_utils.dart';

class VoneImage extends StatelessWidget {
  ///图片宽度
  final double imageWidth;

  ///图片高度
  final double imageHeight;

  ///默认图片
  String? placeholder;

  ///图片地址
  final String imageUrl;

  ///图片形状
  ImageShape shape;

  ///圆角大小
  double radiusSize;

  final BoxFit boxFit;
  final Uint8List kTransparentImage = Uint8List.fromList(<int>[
    0x89,
    0x50,
    0x4E,
    0x47,
    0x0D,
    0x0A,
    0x1A,
    0x0A,
    0x00,
    0x00,
    0x00,
    0x0D,
    0x49,
    0x48,
    0x44,
    0x52,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x01,
    0x08,
    0x06,
    0x00,
    0x00,
    0x00,
    0x1F,
    0x15,
    0xC4,
    0x89,
    0x00,
    0x00,
    0x00,
    0x0A,
    0x49,
    0x44,
    0x41,
    0x54,
    0x78,
    0x9C,
    0x63,
    0x00,
    0x01,
    0x00,
    0x00,
    0x05,
    0x00,
    0x01,
    0x0D,
    0x0A,
    0x2D,
    0xB4,
    0x00,
    0x00,
    0x00,
    0x00,
    0x49,
    0x45,
    0x4E,
    0x44,
    0xAE,
  ]);

  VoneImage(
      {Key? key,
      required this.imageWidth,
      required this.imageHeight,
      this.placeholder,
      required this.imageUrl,
      this.shape = ImageShape.None,
      this.boxFit = BoxFit.cover,
      this.radiusSize = 0})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    String packageName = "vone_ipfs";
    if(placeholder!=null && placeholder!.isNotEmpty){
      packageName = IPFSUtils.getPackageName().toString();
    }
    if(placeholder==null || placeholder!.isEmpty){
      placeholder = 'assets/images/ic_image_loading.png';
    }

    print("------${placeholder}");
    Widget child;

    final isNetwork = imageUrl.startsWith(RegExp(r'^http'));
    if (isNetwork) {
      if (imageUrl.endsWith("null") || imageUrl.endsWith("/")) {
        child = Image.asset(
          placeholder!,
          width: imageWidth,
          height: imageHeight,
          fit: boxFit,
          package: packageName,
        );
      } else {
        child = Stack(children: [
          SizedBox(
            width: imageWidth,
            height: imageHeight,
            child: const Center(child: CircularProgressIndicator()),
          ),
          FadeInImage.memoryNetwork(
              placeholder: kTransparentImage,
              image: imageUrl,
              width: imageWidth,
              height: imageHeight,
              fit: boxFit,
              imageErrorBuilder: (context, error, _) {
                return Image.asset(
                  placeholder!,
                  width: imageWidth,
                  height: imageHeight,
                  package: packageName,
                  fit: boxFit,
                );
              })
        ],);
      }
    } else {
      if (imageUrl.isEmpty || imageUrl == 'null') {
        child = Image.asset(
          placeholder!,
          fit: boxFit,
          width: imageWidth,
          height: imageHeight,
          package: packageName,
        );
      } else {
        child = Image.asset(
          imageUrl,
          fit: boxFit,
          width: imageWidth,
          height: imageHeight,
          package: packageName,
        );
      }
    }
    if (shape == ImageShape.FILL) {
      return ClipRRect(
        borderRadius: BorderRadius.circular(radiusSize), // 圆角半径
        child: Container(
          width: imageWidth,
          height: imageHeight,
          child: child,
        ),
      );
    } else if (shape == ImageShape.ROUND) {
      return ClipOval(
        child: Container(
          width: imageWidth,
          height: imageHeight,
          child: child,
        ),
      );
    } else {
      return child;
    }
  }
}

enum ImageShape {
  ///原图
  None,

  ///圆角
  FILL,

  ///圆形
  ROUND
}

